==> muse-json-generator-2.0.0.tgz: package/lib/generator.js <==
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var honoka_1 = require("honoka");
var Config_1 = require("./Config");
honoka_1.default.defaults.baseURL = Config_1.default.NeteaseBaseURL;
function parseResponse(response) {
    try {
        response = JSON.parse(response);
    }
    catch (e) {
        throw new Error('response is not a valid json string');
    }
    if (response.code !== 200) {
        throw new Error('response code is not valid');
    }
    return response;
}
function joinArtists(artists) {
    return artists.map(function (artist) { return artist.name; }).join('/');
}
function generator() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    return __awaiter(this, void 0, void 0, function () {
        var options, lastItem, playlist, _loop_1, _i, args_1, id;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (args.length === 0) {
                        throw new Error('invalid input');
                    }
                    options = {};
                    lastItem = args[args.length - 1];
                    if (typeof lastItem === 'object') {
                        options = lastItem;
                        args.pop();
                    }
                    playlist = [];
                    _loop_1 = function (id) {
                        var item, songResponse, lyricResponse;
                        return __generator(this, function (_a) {
                            switch (_a.label) {
                                case 0:
                                    if (!/^[0-9]*[1-9][0-9]*$/.test(id)) {
                                        throw new Error('invalid song ID');
                                    }
                                    item = {};
                                    return [4, honoka_1.default.get("/song/detail/?id=" + id + "&ids=%5B" + id + "%5D")];
                                case 1:
                                    songResponse = _a.sent();
                                    songResponse = parseResponse(songResponse);
                                    if (!songResponse.songs[0]) {
                                        throw new Error("song ID " + id + " is not exist");
                                    }
                                    songResponse = songResponse.songs[0];
                                    item.title = songResponse.name;
                                    item.artist =
                                        songResponse.artists.length > 1
                                            ? joinArtists(songResponse.artists)
                                            : songResponse.artists[0].name;
                                    item.cover = songResponse.album.picUrl;
                                    item.src = Config_1.default.KotoriBaseURL + "/netease/" + id + ".mp3";
                                    if (!options.temporary) return [3, 3];
                                    return [4, honoka_1.default.get(item.src, {
                                            redirect: 'manual'
                                        })];
                                case 2:
                                    _a.sent();
                                    item.src = honoka_1.default.response.headers.get('location');
                                    _a.label = 3;
                                case 3: return [4, honoka_1.default.get("/song/lyric?os=pc&id=" + id + "&lv=-1&kv=-1&tv=-1")];
                                case 4:
                                    lyricResponse = _a.sent();
                                    lyricResponse = parseResponse(lyricResponse);
                                    item.lyric = lyricResponse.lrc.lyric;
                                    item.translation = lyricResponse.tlyric.lyric;
                                    ['lyric', 'translation'].forEach(function (key) {
                                        if (item[key] === null) {
                                            delete item[key];
                                        }
                                    });
                                    playlist.push(item);
                                    return [2];
                            }
                        });
                    };
                    _i = 0, args_1 = args;
                    _a.label = 1;
                case 1:
                    if (!(_i < args_1.length)) return [3, 4];
                    id = args_1[_i];
                    return [5, _loop_1(id)];
                case 2:
                    _a.sent();
                    _a.label = 3;
                case 3:
                    _i++;
                    return [3, 1];
                case 4: return [2, JSON.stringify(playlist, null, 2)];
            }
        });
    });
}
module.exports = generator;

==> muse-json-generator-2.0.1.tgz: package/lib/generator.js <==
"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : new P(function (resolve) { resolve(result.value); }).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __generator = (this && this.__generator) || function (thisArg, body) {
    var _ = { label: 0, sent: function() { if (t[0] & 1) throw t[1]; return t[1]; }, trys: [], ops: [] }, f, y, t, g;
    return g = { next: verb(0), "throw": verb(1), "return": verb(2) }, typeof Symbol === "function" && (g[Symbol.iterator] = function() { return this; }), g;
    function verb(n) { return function (v) { return step([n, v]); }; }
    function step(op) {
        if (f) throw new TypeError("Generator is already executing.");
        while (_) try {
            if (f = 1, y && (t = y[op[0] & 2 ? "return" : op[0] ? "throw" : "next"]) && !(t = t.call(y, op[1])).done) return t;
            if (y = 0, t) op = [0, t.value];
            switch (op[0]) {
                case 0: case 1: t = op; break;
                case 4: _.label++; return { value: op[1], done: false };
                case 5: _.label++; y = op[1]; op = [0]; continue;
                case 7: op = _.ops.pop(); _.trys.pop(); continue;
                default:
                    if (!(t = _.trys, t = t.length > 0 && t[t.length - 1]) && (op[0] === 6 || op[0] === 2)) { _ = 0; continue; }
                    if (op[0] === 3 && (!t || (op[1] > t[0] && op[1] < t[3]))) { _.label = op[1]; break; }
                    if (op[0] === 6 && _.label < t[1]) { _.label = t[1]; t = op; break; }
                    if (t && _.label < t[2]) { _.label = t[2]; _.ops.push(op); break; }
                    if (t[2]) _.ops.pop();
                    _.trys.pop(); continue;
            }
            op = body.call(thisArg, _);
        } catch (e) { op = [6, e]; y = 0; } finally { f = t = 0; }
        if (op[0] & 5) throw op[1]; return { value: op[0] ? op[1] : void 0, done: true };
    }
};
var honoka_1 = require("honoka");
var _ = require("lodash");
var Config_1 = require("./Config");
honoka_1.default.defaults.baseURL = Config_1.default.NeteaseBaseURL;
function parseResponse(response) {
    try {
        response = JSON.parse(response);
    }
    catch (e) {
        throw new Error('response is not a valid json string');
    }
    if (response.code !== 200) {
        throw new Error('response code is not valid');
    }
    return response;
}
function joinArtists(artists) {
    return artists.map(function (artist) { return artist.name; }).join('/');
}
function generator() {
    var args = [];
    for (var _i = 0; _i < arguments.length; _i++) {
        args[_i] = arguments[_i];
    }
    return __awaiter(this, void 0, void 0, function () {
        var options, lastItem, playlist, _i, args_1, id, item, songResponse, lyricResponse;
        return __generator(this, function (_a) {
            switch (_a.label) {
                case 0:
                    if (args.length === 0) {
                        throw new Error('invalid input');
                    }
                    options = {};
                    lastItem = args[args.length - 1];
                    if (typeof lastItem === 'object') {
                        options = lastItem;
                        args.pop();
                    }
                    playlist = [];
                    _i = 0, args_1 = args;
                    _a.label = 1;
                case 1:
                    if (!(_i < args_1.length)) return [3, 7];
                    id = args_1[_i];
                    if (!/^[0-9]*[1-9][0-9]*$/.test(id)) {
                        throw new Error('invalid song ID');
                    }
                    item = {};
                    return [4, honoka_1.default.get("/song/detail/?id=" + id + "&ids=%5B" + id + "%5D")];
                case 2:
                    songResponse = _a.sent();
                    songResponse = parseResponse(songResponse);
                    if (!songResponse.songs[0]) {
                        throw new Error("song ID " + id + " is not exist");
                    }
                    songResponse = songResponse.songs[0];
                    item.title = songResponse.name;
                    item.artist =
                        songResponse.artists.length > 1
                            ? joinArtists(songResponse.artists)
                            : songResponse.artists[0].name;
                    item.cover = songResponse.album.picUrl;
                    item.src = Config_1.default.KotoriBaseURL + "/netease/" + id + ".mp3";
                    if (!options.temporary) return [3, 4];
                    return [4, honoka_1.default.get(item.src, {
                            redirect: 'manual'
                        })];
                case 3:
                    _a.sent();
                    item.src = honoka_1.default.response.headers.get('location');
                    _a.label = 4;
                case 4: return [4, honoka_1.default.get("/song/lyric?os=pc&id=" + id + "&lv=-1&kv=-1&tv=-1")];
                case 5:
                    lyricResponse = _a.sent();
                    lyricResponse = parseResponse(lyricResponse);
                    item.lyric = _.get(lyricResponse, 'lrc.lyric');
                    item.translation = _.get(lyricResponse, 'tlyric.lyric');
                    playlist.push(item);
                    _a.label = 6;
                case 6:
                    _i++;
                    return [3, 1];
                case 7: return [2, JSON.stringify(playlist, null, 2)];
            }
        });
    });
}
module.exports = generator;
